==> api-vertx-client-0.7.20.6.1-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/RestrictionMosaicRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicAddressRestrictionDTO;
import io.nem.sdk.openapi.vertx.model.MosaicGlobalRestrictionDTO;
import io.nem.sdk.openapi.vertx.model.MosaicIds;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2020-01-01T18:24:23.294947664-03:00[America/Argentina/Buenos_Aires]")
public class RestrictionMosaicRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi delegate;

	public RestrictionMosaicRoutesApi(io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get mosaic address restrictions for a given mosaic and account identifier.
     * Get mosaic address restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicAddressRestriction(String mosaicId, String accountId, Handler<AsyncResult<MosaicAddressRestrictionDTO>> resultHandler) {
        delegate.getMosaicAddressRestriction(mosaicId, accountId, resultHandler);
    }

    /**
     * Get mosaic address restrictions for a given mosaic and account identifier.
     * Get mosaic address restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicAddressRestrictionDTO> rxGetMosaicAddressRestriction(String mosaicId, String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicAddressRestriction(mosaicId, accountId, fut);
        }));
    }
    /**
     * Get mosaic address restrictions for a given mosaic and account identifiers array.
     * Get mosaic address restrictions.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicAddressRestrictions(String mosaicId, AccountIds accountIds, Handler<AsyncResult<List<MosaicAddressRestrictionDTO>>> resultHandler) {
        delegate.getMosaicAddressRestrictions(mosaicId, accountIds, resultHandler);
    }

    /**
     * Get mosaic address restrictions for a given mosaic and account identifiers array.
     * Get mosaic address restrictions.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicAddressRestrictionDTO>> rxGetMosaicAddressRestrictions(String mosaicId, AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicAddressRestrictions(mosaicId, accountIds, fut);
        }));
    }
    /**
     * Get mosaic global restriction for a given mosaic identifier.
     * Get mosaic global restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicGlobalRestriction(String mosaicId, Handler<AsyncResult<MosaicGlobalRestrictionDTO>> resultHandler) {
        delegate.getMosaicGlobalRestriction(mosaicId, resultHandler);
    }

    /**
     * Get mosaic global restriction for a given mosaic identifier.
     * Get mosaic global restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicGlobalRestrictionDTO> rxGetMosaicGlobalRestriction(String mosaicId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicGlobalRestriction(mosaicId, fut);
        }));
    }
    /**
     * Get mosaic global restrictions for an array of mosaics.
     * Get mosaic global restrictions.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicGlobalRestrictions(MosaicIds mosaicIds, Handler<AsyncResult<List<MosaicGlobalRestrictionDTO>>> resultHandler) {
        delegate.getMosaicGlobalRestrictions(mosaicIds, resultHandler);
    }

    /**
     * Get mosaic global restrictions for an array of mosaics.
     * Get mosaic global restrictions.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicGlobalRestrictionDTO>> rxGetMosaicGlobalRestrictions(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicGlobalRestrictions(mosaicIds, fut);
        }));
    }

    public static RestrictionMosaicRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi arg) {
        return arg != null ? new RestrictionMosaicRoutesApi(arg) : null;
    }
}

==> api-vertx-client-0.7.21-sources.jar: io/nem/sdk/openapi/vertx/api/rxjava/RestrictionMosaicRoutesApi.java <==
package io.nem.sdk.openapi.vertx.api.rxjava;

import io.nem.sdk.openapi.vertx.model.AccountIds;
import io.nem.sdk.openapi.vertx.model.ModelError;
import io.nem.sdk.openapi.vertx.model.MosaicAddressRestrictionDTO;
import io.nem.sdk.openapi.vertx.model.MosaicGlobalRestrictionDTO;
import io.nem.sdk.openapi.vertx.model.MosaicIds;

import java.util.*;

import rx.Single;
import io.vertx.core.AsyncResult;
import io.vertx.core.Handler;

@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2019-11-23T10:26:45.594287+01:00[Europe/Madrid]")
public class RestrictionMosaicRoutesApi {

	private final io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi delegate;

	public RestrictionMosaicRoutesApi(io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi delegate) {
	    this.delegate = delegate;
    }

	public io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi getDelegate() {
	    return delegate;
	}

    /**
     * Get mosaic address restrictions for a given mosaic and account identifier.
     * Get mosaic address restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountId Account public key or address. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicAddressRestriction(String mosaicId, String accountId, Handler<AsyncResult<MosaicAddressRestrictionDTO>> resultHandler) {
        delegate.getMosaicAddressRestriction(mosaicId, accountId, resultHandler);
    }

    /**
     * Get mosaic address restrictions for a given mosaic and account identifier.
     * Get mosaic address restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountId Account public key or address. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicAddressRestrictionDTO> rxGetMosaicAddressRestriction(String mosaicId, String accountId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicAddressRestriction(mosaicId, accountId, fut);
        }));
    }
    /**
     * Get mosaic address restrictions for a given mosaic and account identifiers array.
     * Get mosaic address restrictions.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountIds  (optional)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicAddressRestrictions(String mosaicId, AccountIds accountIds, Handler<AsyncResult<List<MosaicAddressRestrictionDTO>>> resultHandler) {
        delegate.getMosaicAddressRestrictions(mosaicId, accountIds, resultHandler);
    }

    /**
     * Get mosaic address restrictions for a given mosaic and account identifiers array.
     * Get mosaic address restrictions.
     * @param mosaicId Mosaic identifier. (required)
     * @param accountIds  (optional)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicAddressRestrictionDTO>> rxGetMosaicAddressRestrictions(String mosaicId, AccountIds accountIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicAddressRestrictions(mosaicId, accountIds, fut);
        }));
    }
    /**
     * Get mosaic global restriction for a given mosaic identifier.
     * Get mosaic global restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicGlobalRestriction(String mosaicId, Handler<AsyncResult<MosaicGlobalRestrictionDTO>> resultHandler) {
        delegate.getMosaicGlobalRestriction(mosaicId, resultHandler);
    }

    /**
     * Get mosaic global restriction for a given mosaic identifier.
     * Get mosaic global restriction.
     * @param mosaicId Mosaic identifier. (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<MosaicGlobalRestrictionDTO> rxGetMosaicGlobalRestriction(String mosaicId) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicGlobalRestriction(mosaicId, fut);
        }));
    }
    /**
     * Get mosaic global restrictions for an array of mosaics.
     * Get mosaic global restrictions.
     * @param mosaicIds  (required)
     * @param resultHandler Asynchronous result handler
     */
    public void getMosaicGlobalRestrictions(MosaicIds mosaicIds, Handler<AsyncResult<List<MosaicGlobalRestrictionDTO>>> resultHandler) {
        delegate.getMosaicGlobalRestrictions(mosaicIds, resultHandler);
    }

    /**
     * Get mosaic global restrictions for an array of mosaics.
     * Get mosaic global restrictions.
     * @param mosaicIds  (required)
     * @return Asynchronous result handler (RxJava Single)
     */
    public Single<List<MosaicGlobalRestrictionDTO>> rxGetMosaicGlobalRestrictions(MosaicIds mosaicIds) {
        return Single.create(new io.vertx.rx.java.SingleOnSubscribeAdapter<>(fut -> {
            delegate.getMosaicGlobalRestrictions(mosaicIds, fut);
        }));
    }

    public static RestrictionMosaicRoutesApi newInstance(io.nem.sdk.openapi.vertx.api.RestrictionMosaicRoutesApi arg) {
        return arg != null ? new RestrictionMosaicRoutesApi(arg) : null;
    }
}
